| Title: | Top Chef Data |
|---|---|
| Description: | Several datasets which describe the chef contestants in Top Chef, the challenges that they compete in, and the results of those challenges. This data is useful for practicing data wrangling, graphing, and analyzing how each season of Top Chef played out. |
| Authors: | Levitz Carly E [cre, aut, cph]
|
| Maintainer: | Levitz Carly E <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-06-08 05:30:29 UTC |
| Source: | https://github.com/celevitz/topchef |
A dataset containing information about each challenge that the Chefs compete in
data(challengedescriptions)data(challengedescriptions)
This data frame contains the following columns:
seasonName of season
seasonNumberSeason number
seriesTop Chef US (listed as US); Top Chef US Masters (listed as US Masters); Top Chef Canada (listed as Canada)
episodeEpisode number
challengeTypeChallenge type: qualifying challenge, elimination, quickfire, sudden death quickfire, quickfire elimination, battle of the sous chefs
outcomeTypeIs the challenge run as a team or as an individual?
challengeDescriptionDescription of the challenge
shopTimeIf they go shopping, how long do they have? Unit is minutes
shopBudgetIf they go shopping, what is their budget? Unit is dollars unless otherwise specified.
prepTimeIf they have prep time, how long do they have? Unit is minutes
cookTimeHow long they have to cook (in minutes)
productPlacementList of products promoted in the challenge, other than the usual series-wide product placement. Will be blank if none were mentioned
advantageIf an advantage is offered to the winner of the challenge, it will be listed here: e.g., Immunity, choosing a protein in the elimination challenge, choosing your team in the elimination challenge. Will be blank if none were mentioned.
lastChanceKitchenWinnerEntersIf someone comes in from Last Chance Kitchen at this challenge, their name will be listed here. Will be blank for all other challenges.
restaurantWarWinnerRole played by the winner of restaurant wars: Executive Chef, Front of House, the full team, Line Cook, Roles Rotated, or No one won. Will only have values for Restaurant War episodes.
restaurantWarEliminatedRole played by the Chef eliminated after restaurant wars: Executive Chef, Front of House, the full team, Line Cook, Roles Rotated. Will only have values for Restaurant War episodes.
didJudgesVisitWinningTeamFirstCategorical variable of which team was shown serving the judges first. Will only have values for Restaurant Wars episodes.
https://en.wikipedia.org/wiki/Top_Chef
library(dplyr) library(tidyr) challengedescriptions %>% group_by(series,season,outcomeType) %>% summarise(n=n()) %>% pivot_wider(names_from=outcomeType,values_from=n)library(dplyr) library(tidyr) challengedescriptions %>% group_by(series,season,outcomeType) %>% summarise(n=n()) %>% pivot_wider(names_from=outcomeType,values_from=n)
A dataset containing win and loss data for each chef in each episode
data(challengewins)data(challengewins)
This data frame contains the following columns:
seasonName of season
seasonNumberSeason number
seriesTop Chef US (listed as US); Top Chef US Masters (listed as US Masters); Top Chef Canada (listed as Canada)
episodeEpisode number
inCompetitionTrue / false for whether the Chef was still in the competition at the time of the challenge
immuneTrue / false for whether that Chef was immune from being eliminated for challenge
advantagedescribes what advantage that chef had in that challenge
chefName of chef
challengeTypeChallenge type: qualifying challenge, elimination, quickfire, sudden death quickfire, quickfire elimination, battle of the sous chefs
outcomeResult for each Chef in the competition for that challenge
ratingNumeric rating provided to chefs in Top Chef US Masters Seasons 1 and 2. Will be blank for all other seasons.
https://en.wikipedia.org/wiki/Top_Chef
library(dplyr) library(tidyr) challengewins %>% group_by(outcome) %>% summarise(n=n())library(dplyr) library(tidyr) challengewins %>% group_by(outcome) %>% summarise(n=n())
A dataset containing information on each Chef for each season. As of now, it has data for all Top Chef US seasons, Top Chef Masters (US), and one season of Top Chef Canada.
data(chefdetails)data(chefdetails)
This data frame contains the following columns:
nameChef name (full name)
chefShorter version of the chef's name
hometownChef's hometown, if known
cityCity in which the Chef lived at the time of show
stateState in which the Chef lived at the time of the show
ageAge of Chef at the time of the show
seasonName of season
seasonNumberSeason number
seriesTop Chef US (listed as US); Top Chef US Masters (listed as US Masters); Top Chef Canada (listed as Canada)
placementFinal result of the Chef.
personOfColorFlag for whether the Chef is a person of color. Will be blank if they are not
occupationOccupation of Chef at time of show, if known
occupation_categoryCategorization of occupation
genderGender of Chef
https://en.wikipedia.org/wiki/Top_Chef
library(dplyr) library(tidyr) chefdetails %>% filter(season == "World All Stars")library(dplyr) library(tidyr) chefdetails %>% filter(season == "World All Stars")
A dataset containing information about each episode
data(episodeinfo)data(episodeinfo)
This data frame contains the following columns:
seasonName of season
seasonNumberSeason number
seriesTop Chef US (listed as US); Top Chef US Masters (listed as US Masters); Top Chef Canada (listed as Canada); US LCK (Last Chance Kitchen); Just Desserts
overallEpisodeNumberRunning number of episode within the series
episodeEpisode number
episodeNameName of episode
airDateDate the episode originally aired
nCompetitorsNumber of Chefs still in the competition
https://en.wikipedia.org/wiki/Top_Chef
library(dplyr) library(tidyr) episodeinfo %>% filter(season=="World All Stars")library(dplyr) library(tidyr) episodeinfo %>% filter(season=="World All Stars")
A dataset containing information about who were the guest judges for each challenge
data(judges)data(judges)
This data frame contains the following columns:
seasonName of season
seasonNumberSeason number
seriesTop Chef US (listed as US); Top Chef US Masters (listed as US Masters); Top Chef Canada (listed as Canada); US LCK (Last Chance Kitchen); Just Desserts
episodeEpisode number
challengeTypeChallenge type: qualifying challenge, elimination, quickfire, sudden death quickfire, quickfire elimination, battle of the sous chefs
outcomeTypeIs the challenge run as a team or as an individual?
guestJudgeName of guest judge
genderGender of Chef
personOfColorFlag for whether the Chef is a person of color. Will be blank if they are not
competedOnTCWill have a value of Yes if they competed on a season of Top Chef
otherShowsInformation about other shows that this individual has appeared on
https://en.wikipedia.org/wiki/Top_Chef
library(dplyr) library(tidyr) judges %>% filter(guestJudge == "Eric Ripert") %>% group_by(challengeType) %>% summarise(n=n())library(dplyr) library(tidyr) judges %>% filter(guestJudge == "Eric Ripert") %>% group_by(challengeType) %>% summarise(n=n())
A dataset containing information about rewards and prizes won by challenge
data(rewards)data(rewards)
This data frame contains the following columns:
seasonName of season
seasonNumberSeason number
seriesTop Chef US (listed as US); Top Chef US Masters (listed as US Masters); Top Chef Canada (listed as Canada); US LCK (Last Chance Kitchen); Just Desserts
episodeEpisode number
challengeTypeChallenge type: qualifying challenge, elimination, quickfire, sudden death quickfire, quickfire elimination, battle of the sous chefs
outcomeTypeIs the challenge run as a team or as an individual?
rewardTypeVariable describing whether the reward is money or a prize
rewardDescription of the full reward
chefName of chef
https://en.wikipedia.org/wiki/Top_Chef
library(dplyr) library(tidyr) rewards %>% filter(rewardType == "Money") %>% mutate(reward=as.numeric(reward)) %>% group_by(season) %>% summarise(total=sum(reward))library(dplyr) library(tidyr) rewards %>% filter(rewardType == "Money") %>% mutate(reward=as.numeric(reward)) %>% group_by(season) %>% summarise(total=sum(reward))
Calculates the Index score for each person within a season of Top Chef.
weightedindex( seriesname, seasonnumberofchoice, numberofelimchalls, numberofquickfires )weightedindex( seriesname, seasonnumberofchoice, numberofelimchalls, numberofquickfires )
seriesname |
Values can be: US, US Masters, Canada |
seasonnumberofchoice |
Integer of the season number within the series |
numberofelimchalls |
Number of elimination challenges you want to include in the index. Must be greater than 0 |
numberofquickfires |
Number of quickfire challenges you want to include in the index. Must be greater than 0. |
The result of elimination challenges and quickfire challenges are weighted. Scoring: Elimination win = +7 points. Elimination high = +3 points. Elimination low = -3 points. Eliminated = -7 points. Quickfire win = +4 points. Quickfire high = +2 points. Quickfire low = -2 points. Combines Sudden Death Quickfires with Eliminations Excludes Qualifying Challenges Holding constant the number of elimination challenges and quickfire challenges will allow comparison across seasons if you want
Tibble of index score for each contestant in that season and their placement